==> plugin_codelab_new-0.0.1.tar.gz: lib/pages/home_page.dart <==
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:localstorage/localstorage.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:number_display/number_display.dart';
import 'dart:async';
import 'package:intl/intl.dart';
import 'package:datetime_picker_formfield/datetime_picker_formfield.dart';
import 'package:plugin_codelab_new/bloc/feed_cubit.dart';
import 'package:plugin_codelab_new/models/post_model.dart';
import 'package:plugin_codelab_new/models/report_sub_type_model.dart';
import 'package:plugin_codelab_new/models/report_type_model.dart';
import 'package:plugin_codelab_new/pages/share_post_page.dart';
import 'package:plugin_codelab_new/widgets/loadingButtonIndicator.dart';
import 'package:plugin_codelab_new/widgets/post.dart';
// import 'package:provider/provider.dart';

// import 'chat/providers/messages_provider.dart';
// import 'package:feed_app/pages/chat/models/message.dart';

final lastDate = new DateTime(
  DateTime.now().year - 10,
  DateTime.now().month,
);

String selectedValue = lastDate.toString();

class HomePage extends StatefulWidget {
  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  FeedCubit feedCubit;
  List<PostModel> postsList = [];
  List<PostModel> postsListFilter = [];
  List<FeedPost> postsListWidgets = [];
  var _scrollController = ScrollController();

  @override
  void initState() {
    postsListFilter = [];
    postsListWidgets = [];
    feedCubit = BlocProvider.of<FeedCubit>(context);
    getPostData();

    _scrollController.addListener(_onScroll);
    super.initState();
  }

  dispose() {
    storage.dispose();
    super.dispose();
  }

  void _onScroll() {
    if (_scrollController.position.pixels ==
        _scrollController.position.maxScrollExtent) {
      getPostData();
    }
  }

  getPostData() async {
    await getLikeSubId();
    await _loadData().then(
      (data) {
        setState(
          () {
            postsListFilter = data;
          },
        );
      },
    );
  }

  String filterDate = DateTime.now().toString();
  final storage = new LocalStorage('my_data');
  final display = createDisplay(
    length: 4,
    separator: ',',
    decimal: 2,
  );
  double defaultScreenWidth = 393.0;
  double defaultScreenHeight = 534.0;

  List<ReportTypeModel> reportsTypeList = [];
  List<ReportSubTypeModel> reportsSubTypeList = [];
  // UserModel user;
  int likeId;
  int dislikeId;
  int saveId;

  void getPostsListFilter() {
    List<PostModel> postsListTemp = [];

    for (var i = 0; i < postsList.length; i++) {
      if (filter(
          createdAt: postsList[i].createdAt, selectedDate: selectedValue)) {
        postsListTemp.add(postsList[i]);
      }
    }
    setState(
      () {
        postsListFilter = [];
        for (var i = 0; i < postsListTemp.length; i++) {
          postsListFilter.add(postsListTemp[i]);
        }
      },
    );
  }

  Future getLikeSubId() async {
    reportsSubTypeList = await feedCubit.feedRepository.fetchAllSubType();
    for (var i = 0; i < reportsSubTypeList.length; i++) {
      if (likeId == null || dislikeId == null || saveId == null) {
        if (reportsSubTypeList[i].type == "Like") {
          likeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Dislike") {
          dislikeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Save") {
          saveId = reportsSubTypeList[i].id;
        }
      } else {
        break;
      }
    }
  }

  bool filter({@required DateTime createdAt, @required String selectedDate}) {
    DateTime fromDate = createdAt;
    DateTime toDate = new DateFormat("yyyy-MM-dd hh:mm:ss").parse(selectedDate);
    if (fromDate.isAfter(toDate) || toDate == fromDate) {
      return true;
    }
    return false;
  }

  int currentUserId = 5;
  @override
  Widget build(BuildContext context) {
    int currentUserId = 5;
    // storage.getItem("userId");
    return ScreenUtilInit(
      designSize: Size(defaultScreenWidth, defaultScreenHeight),
      allowFontScaling: true,
      builder: () => LayoutBuilder(
        builder: (_, BoxConstraints constraints) {
          return MaterialApp(
            home: Scaffold(
              // backgroundColor: Color(0xFFCFD8DC),
              appBar: PreferredSize(
                  preferredSize: Size.fromHeight(70.0),
                  child: AppBar(
                    backgroundColor: Color(0xFF083356),
                    leading: GestureDetector(
                        onTap: () {
                          Navigator.pop(context);
                        },
                        child: Icon(Icons.account_circle_outlined,
                            size: 35, color: Colors.white)),
                    title: Padding(
                      padding: EdgeInsets.only(
                          left: ScreenUtil().setWidth(50),
                          top: ScreenUtil().setWidth(9)),
                      child: Text(
                        "Phone.do Feed",
                        style: TextStyle(color: Colors.white),
                      ),
                    ),
                  )),
              body: postsListFilter.length < 1
                  ? Center(child: LoadingIndicatorDark())
                  : Column(
                      crossAxisAlignment: CrossAxisAlignment.stretch,
                      children: [
                        // Padding(
                        //   padding: EdgeInsets.all(
                        //     ScreenUtil().setHeight(20),
                        //   ),
                        //   child:
                        _buildDateField(),
                        // ),
                        Expanded(
                          child: Stack(
                            children: [
                              RefreshIndicator(
                                onRefresh: () {
                                  return _loadData();
                                },
                                child: ListView.separated(
                                  cacheExtent: 9999,
                                  itemCount: postsListFilter.length,
                                  itemBuilder:
                                      (BuildContext context, int index) {
                                    PostModel post = postsListFilter[index];
                                    List<String> images = postsListFilter[index]
                                        .attachedUrl
                                        .split(",");
                                    return Container(
                                      decoration: BoxDecoration(
                                          border: Border(
                                              bottom: BorderSide(
                                                  width: 15,
                                                  color: Color(0xffE8ECEF)))),
                                      child: FeedPost(
                                        postData: post,
                                        currentUserId: currentUserId,
                                        images: images,
                                        likeId: likeId,
                                        dislikeId: dislikeId,
                                        saveId: saveId,
                                      ),
                                    );
                                  },
                                  separatorBuilder:
                                      (BuildContext context, int index) =>
                                          const Divider(),
                                ),
                              ),
                              Align(
                                alignment: Alignment(0.8, 0.85),
                                child: Container(
                                    decoration: BoxDecoration(
                                      shape: BoxShape.circle,
                                      boxShadow: [
                                        BoxShadow(
                                          color: Colors.grey,
                                          blurRadius: 5.0,
                                          spreadRadius: 1.0,
                                        )
                                      ],
                                    ),
                                    child: ClipOval(
                                        child: Material(
                                            color: Color(
                                                0xFF3DD598), // button color
                                            child: InkWell(
                                              splashColor: Color(
                                                  0xFFFCA64F), // inkwell color
                                              child: SizedBox(
                                                width: 70,
                                                height: 70,
                                                child: Icon(Icons.add,
                                                    size: 50.0,
                                                    color: Colors.white),
                                              ),
                                              onTap: () {
                                                Navigator.push(
                                                  context,
                                                  MaterialPageRoute(
                                                      builder: (context) =>
                                                          SharePostPage()),
                                                );
                                              },
                                            )))),
                              ),
                            ],
                          ),
                        ),
                      ],
                    ),
            ),
          );
        },
      ),
    );
  }

  _buildDateField() {
    final format = DateFormat("dd/MM/yyyy");

    final TextEditingController controller = TextEditingController();
    final now = DateTime.now();

    final nextYear = new DateTime(
      now.year,
      now.month,
      now.day,
    );
    return Container(
        decoration: BoxDecoration(
            border: Border(
          top: BorderSide(width: 15, color: Color(0xffE8ECEF)),
          bottom: BorderSide(width: 15, color: Color(0xffE8ECEF)),
        )),
        height: ScreenUtil().setHeight(70),
        child: Padding(
          padding: EdgeInsets.all(ScreenUtil().setWidth(15)),
          child: Container(
            decoration: BoxDecoration(
                color: Color(0xffE8ECEF),
                borderRadius: BorderRadius.circular(7)),
            margin: EdgeInsets.only(top: ScreenUtil().setHeight(5)),
            child: DateTimeField(
              textAlign: TextAlign.center,
              readOnly: true,
              onChanged: (value) {
                setState(
                  () {
                    selectedValue = value.toString();
                  },
                );
                getPostsListFilter();
              },
              controller: controller,
              format: format,
              onShowPicker: (context, currentValue) {
                return showDatePicker(
                    context: context,
                    firstDate: lastDate,
                    initialDate: currentValue ?? DateTime.now(),
                    lastDate: nextYear);
              },
              decoration: new InputDecoration(
                  labelText: " filter...",
                  labelStyle: TextStyle(color: Color(0xff98A9BC))),
            ),
          ),
        ));
  }

  Future<List<PostModel>> _loadData() async {
    List<PostModel> posts = await feedCubit.feedRepository.loadPosts();
    this.setState(() {
      postsListFilter = posts;
      postsList = posts;
    });
    return posts;
  }
}

==> plugin_codelab_new-0.0.2.tar.gz: lib/pages/home_page.dart <==
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:number_display/number_display.dart';
import 'dart:async';
import 'package:intl/intl.dart';
import 'package:datetime_picker_formfield/datetime_picker_formfield.dart';
import 'package:plugin_codelab_new/bloc/feed_cubit.dart';
import 'package:plugin_codelab_new/models/post_model.dart';
import 'package:plugin_codelab_new/models/report_sub_type_model.dart';
import 'package:plugin_codelab_new/models/report_type_model.dart';
import 'package:plugin_codelab_new/models/user_model.dart';
import 'package:plugin_codelab_new/pages/my_feed.dart';
import 'package:plugin_codelab_new/pages/share_post_page.dart';
import 'package:plugin_codelab_new/widgets/loadingButtonIndicator.dart';
import 'package:plugin_codelab_new/widgets/post.dart';

final lastDate = new DateTime(
  DateTime.now().year - 10,
  DateTime.now().month,
);

String selectedValue = lastDate.toString();

class HomePage extends StatefulWidget {
  const HomePage({
    Key key,
    @required this.token,
    @required this.firstName,
    @required this.lastName,
    @required this.about,
    @required this.profileImg,
  }) : super(key: key);

  final String token;
  final String firstName;
  final String lastName;
  final String about;
  final String profileImg;

  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  FeedCubit feedCubit;
  UserModel currentUser;
  List<PostModel> postsList = [];
  List<PostModel> postsListFilter = [];
  List<FeedPost> postsListWidgets = [];
  var _scrollController = ScrollController();

  @override
  void initState() {
    postsListFilter = [];
    postsListWidgets = [];
    feedCubit = BlocProvider.of<FeedCubit>(context);
    getCurrentUser();
    getPostData();

    _scrollController.addListener(_onScroll);
    super.initState();
  }

  dispose() {
    super.dispose();
  }

  void _onScroll() {
    if (_scrollController.position.pixels ==
        _scrollController.position.maxScrollExtent) {
      getPostData();
    }
  }

  getPostData() async {
    await getLikeSubId();
    await _loadData().then(
      (data) {
        setState(
          () {
            postsListFilter = data;
          },
        );
      },
    );
  }

  getCurrentUser() async {
    await feedCubit.feedRepository
        .authenticateUser(this.widget.firstName, this.widget.lastName,
            this.widget.about, this.widget.profileImg, this.widget.token)
        .then(
      (data) {
        setState(
          () {
            currentUser = data;
          },
        );
      },
    );
  }

  String filterDate = DateTime.now().toString();
  final display = createDisplay(
    length: 4,
    separator: ',',
    decimal: 2,
  );
  double defaultScreenWidth = 393.0;
  double defaultScreenHeight = 534.0;

  List<ReportTypeModel> reportsTypeList = [];
  List<ReportSubTypeModel> reportsSubTypeList = [];
  int likeId;
  int dislikeId;
  int saveId;

  void getPostsListFilter() {
    List<PostModel> postsListTemp = [];

    for (var i = 0; i < postsList.length; i++) {
      if (filter(
          createdAt: postsList[i].createdAt, selectedDate: selectedValue)) {
        postsListTemp.add(postsList[i]);
      }
    }
    setState(
      () {
        postsListFilter = [];
        for (var i = 0; i < postsListTemp.length; i++) {
          postsListFilter.add(postsListTemp[i]);
        }
      },
    );
  }

  Future getLikeSubId() async {
    reportsSubTypeList = await feedCubit.feedRepository.fetchAllSubType();
    for (var i = 0; i < reportsSubTypeList.length; i++) {
      if (likeId == null || dislikeId == null || saveId == null) {
        if (reportsSubTypeList[i].type == "Like") {
          likeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Dislike") {
          dislikeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Save") {
          saveId = reportsSubTypeList[i].id;
        }
      } else {
        break;
      }
    }
  }

  bool filter({@required DateTime createdAt, @required String selectedDate}) {
    DateTime fromDate = createdAt;
    DateTime toDate = new DateFormat("yyyy-MM-dd hh:mm:ss").parse(selectedDate);
    if (fromDate.isAfter(toDate) || toDate == fromDate) {
      return true;
    }
    return false;
  }

  @override
  Widget build(BuildContext context) {
    return ScreenUtilInit(
      designSize: Size(defaultScreenWidth, defaultScreenHeight),
      allowFontScaling: true,
      builder: () => LayoutBuilder(
        builder: (_, BoxConstraints constraints) {
          return MaterialApp(
            home: Scaffold(
              appBar: PreferredSize(
                  preferredSize: Size.fromHeight(70.0),
                  child: AppBar(
                    backgroundColor: Color(0xFF083356),
                    leading: GestureDetector(
                        onTap: () {
                          Navigator.pop(context);
                        },
                        child: GestureDetector(
                            onTap: () {
                              Navigator.push(
                                  context,
                                  MaterialPageRoute(
                                      builder: (context) => MyFeedPage(
                                            currentUser: currentUser,
                                            saveId: saveId,
                                            likeId: likeId,
                                            dislikeId: dislikeId,
                                          )));
                            },
                            child: currentUser != null
                                ? Container(
                                    alignment: Alignment.bottomRight,
                                    child: ClipOval(
                                        child: Image.network(
                                      currentUser.profileImg,
                                      width: ScreenUtil().setWidth(40),
                                      height: ScreenUtil().setWidth(40),
                                      fit: BoxFit.cover,
                                    )))
                                : Icon(Icons.account_circle_outlined,
                                    size: 35, color: Colors.white))),
                    title: Padding(
                      padding: EdgeInsets.only(
                          left: ScreenUtil().setWidth(50),
                          top: ScreenUtil().setWidth(10)),
                      child: Text(
                        "Phone.do Feed",
                        style: TextStyle(color: Colors.white),
                      ),
                    ),
                  )),
              body: postsListFilter.length < 1
                  ? Center(child: LoadingIndicatorDark())
                  : Column(
                      crossAxisAlignment: CrossAxisAlignment.stretch,
                      children: [
                        _buildDateField(),
                        Expanded(
                          child: Stack(
                            children: [
                              RefreshIndicator(
                                onRefresh: () {
                                  return _loadData();
                                },
                                child: ListView.separated(
                                  cacheExtent: 9999,
                                  itemCount: postsListFilter.length,
                                  itemBuilder:
                                      (BuildContext context, int index) {
                                    PostModel post = postsListFilter[index];
                                    List<String> images = postsListFilter[index]
                                        .attachedUrl
                                        .split(",");
                                    return Container(
                                      decoration: BoxDecoration(
                                          border: Border(
                                              bottom: BorderSide(
                                                  width: 15,
                                                  color: Color(0xffE8ECEF)))),
                                      child: FeedPost(
                                        postData: post,
                                        currentUser: currentUser,
                                        images: images,
                                        likeId: likeId,
                                        dislikeId: dislikeId,
                                        saveId: saveId,
                                      ),
                                    );
                                  },
                                  separatorBuilder:
                                      (BuildContext context, int index) =>
                                          const Divider(),
                                ),
                              ),
                              Align(
                                alignment: Alignment(0.8, 0.85),
                                child: Container(
                                    decoration: BoxDecoration(
                                      shape: BoxShape.circle,
                                      boxShadow: [
                                        BoxShadow(
                                          color: Colors.grey,
                                          blurRadius: 5.0,
                                          spreadRadius: 1.0,
                                        )
                                      ],
                                    ),
                                    child: ClipOval(
                                        child: Material(
                                            color: Color(0xFF3DD598),
                                            child: InkWell(
                                              splashColor: Color(0xFFFCA64F),
                                              child: SizedBox(
                                                width: 70,
                                                height: 70,
                                                child: Icon(Icons.add,
                                                    size: 50.0,
                                                    color: Colors.white),
                                              ),
                                              onTap: () {
                                                Navigator.push(
                                                  context,
                                                  MaterialPageRoute(
                                                      builder: (context) =>
                                                          SharePostPage(
                                                              currentUser:
                                                                  currentUser)),
                                                );
                                              },
                                            )))),
                              ),
                            ],
                          ),
                        ),
                      ],
                    ),
            ),
          );
        },
      ),
    );
  }

  _buildDateField() {
    final format = DateFormat("dd/MM/yyyy");

    final TextEditingController controller = TextEditingController();
    final now = DateTime.now();

    final nextYear = new DateTime(
      now.year,
      now.month,
      now.day,
    );
    return Container(
        decoration: BoxDecoration(
            border: Border(
          top: BorderSide(width: 15, color: Color(0xffE8ECEF)),
          bottom: BorderSide(width: 15, color: Color(0xffE8ECEF)),
        )),
        height: ScreenUtil().setHeight(70),
        child: Padding(
          padding: EdgeInsets.all(ScreenUtil().setWidth(15)),
          child: Container(
            decoration: BoxDecoration(
                color: Color(0xffE8ECEF),
                borderRadius: BorderRadius.circular(7)),
            margin: EdgeInsets.only(top: ScreenUtil().setHeight(5)),
            child: DateTimeField(
              textAlign: TextAlign.center,
              readOnly: true,
              onChanged: (value) {
                setState(
                  () {
                    selectedValue = value.toString();
                  },
                );
                getPostsListFilter();
              },
              controller: controller,
              format: format,
              onShowPicker: (context, currentValue) {
                return showDatePicker(
                    context: context,
                    firstDate: lastDate,
                    initialDate: currentValue ?? DateTime.now(),
                    lastDate: nextYear);
              },
              decoration: new InputDecoration(
                  labelText: " filter...",
                  labelStyle: TextStyle(color: Color(0xff98A9BC))),
            ),
          ),
        ));
  }

  Future<List<PostModel>> _loadData() async {
    List<PostModel> posts = await feedCubit.feedRepository.loadPosts();
    this.setState(() {
      postsListFilter = posts;
      postsList = posts;
    });
    return posts;
  }
}
